==> jruby1.0_1.0.2.orig.tar.gz: jruby-1.0.2/src/org/jruby/ast/visitor/rewriter/utils/ShortIfNodeReWriteVisitor.java <==
/***** BEGIN LICENSE BLOCK *****
 * Version: CPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Common Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/cpl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Copyright (C) 2006 Mirko Stocker <me@misto.ch>
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the CPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the CPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/

package org.jruby.ast.visitor.rewriter.utils;

import org.jruby.ast.NewlineNode;
import org.jruby.ast.visitor.rewriter.ReWriteVisitor;
import org.jruby.evaluator.Instruction;

public class ShortIfNodeReWriteVisitor extends ReWriteVisitor {
	
	public ShortIfNodeReWriteVisitor(ReWriterContext config) {
		super(config);
	}
	
	protected void printNewlineAndIndentation() {
		print("; ");
	}
	
	public Instruction visitNewlineNode(NewlineNode iVisited) {
		if (config.getSource().charAt(getEndOffset(iVisited) - 1) == ')') {
			print('(');
			visitNode(iVisited.getNextNode());
			print(')');
		} else {
			print("; ");
			visitNode(iVisited.getNextNode());
		}
		return null;
	}
}

==> jruby1.2_1.2.0.orig.tar.gz: jruby-1.2.0/src/org/jruby/ast/visitor/rewriter/utils/ShortIfNodeReWriteVisitor.java <==
/***** BEGIN LICENSE BLOCK *****
 * Version: CPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Common Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/cpl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Copyright (C) 2006 Mirko Stocker <me@misto.ch>
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the CPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the CPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/

package org.jruby.ast.visitor.rewriter.utils;

import org.jruby.ast.NewlineNode;
import org.jruby.ast.visitor.rewriter.ReWriteVisitor;

public class ShortIfNodeReWriteVisitor extends ReWriteVisitor {
	
	public ShortIfNodeReWriteVisitor(ReWriterContext config) {
		super(config);
	}
	
	protected void printNewlineAndIndentation() {
		print("; ");
	}
	
	public Object visitNewlineNode(NewlineNode iVisited) {
		if (config.getSource().charAt(getEndOffset(iVisited) - 1) == ')') {
			print('(');
			visitNode(iVisited.getNextNode());
			print(')');
		} else {
			print("; ");
			visitNode(iVisited.getNextNode());
		}
		return null;
	}
}
